
;**************************************************************************
;*                    I2C teplomer                                        *
;**************************************************************************
;**************************************************************************
;*          v 0.02 - 18.10.2022                                           *
;**************************************************************************
;*          Hardw.: PIC16F727 used                                        *
;*          TI TMP100 temperature sensore used                            *
;*          19 LEDs indicates the temperature: 13 - 31C                 *
;*          OSC.......: Internal osc. used     POWER.....:   5V extern.   *
;**************************************************************************


;7 yellow LEDs: 13 - 19C
;6 green LEDs : 20 - 25C
;6 red LEDs   : 26 - 31C


;	SDA -- SDA (RC4)
;	SCL -- SCL (RC3)

;keyboard
;	kbdclk  -- RB0
;	kbddata -- RB1


 INCLUDE "P16F727.INC"


_U001			     EQU     B'11000011000100'	;see Page 95 of Datasheet
_U002			     EQU     B'11111111111111'	;see Page 96 of Datasheet

;	__CONFIG	_CONFIG1, _DEBUG_OFF & _PLL_EN & _BORV_2_5 & _BOR_OFF & _CP_OFF & _MCLR_DIS & _PWRT_DIS & _WDT_OFF & _INTRC_OSC_NOCLKOUT
;	__CONFIG	_CONFIG2, _VCAP_DIS


	__CONFIG	_CONFIG1, _U001

	__CONFIG	_CONFIG2, _U002

;==========================================================================
;       Variable Definition
;==========================================================================
TIMER1		EQU	H'20'		;delay routine
TIMER2		EQU	H'21'		; "	"	"
;==========================================================================

		ORG	0		;Reset vector address
		GOTO	RESET		;goto RESET routine when boot.

;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;
;	       **********************************
;              **  RESET :  main boot routine  **
;              **********************************

RESET		nop
PAGE0
;
		BSF	STATUS,RP0	;Switch to register bank 1
		MOVLW	B'11011111'	;Set PIC options (See datasheet Page 113).
		MOVWF	OPTION_REG	;Write the OPTION register.
		;
		CLRF	INTCON		;Disable interrupts

		MOVLW	B'00000000'	;PORTA
		MOVWF	TRISA

		MOVLW	B'00000000'	;PORTB
		MOVWF	TRISB

		MOVLW	B'00000000'	;PORTC
		MOVWF	TRISC

		MOVLW	B'00000000'	;PORTD
		MOVWF	TRISD

		MOVLW	B'11111000'	;PORTE = output; RE3 = input
		MOVWF	TRISE

		BANKSEL ANSELA
		clrf	ANSELA
		clrf	ANSELB
		clrf	ANSELD
		clrf	ANSELE

		bcf	STATUS,RP0	;Switch Back to reg. Bank 0
		bcf	STATUS,RP1
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
main		movlw	H'FF'
		movwf	PORTA
		movwf	PORTB
		movwf	PORTC
		movwf	PORTD
		movwf	PORTE
;----------------------------------------------------------------------------
main_loop	bcf	PORTE,D'000'
		movlw	H'FF'
		movwf	PORTB
		movwf	PORTC
		movwf	PORTA
		call	dr3
;---------------------------------------
		bsf	PORTE,D'000'
		movlw	H'00'
		movwf	PORTB
		movwf	PORTC
		movwf	PORTA
		call	dr3
;---------------------------------------
		goto	main_loop

;--------------------------------------------------------------------------
;		*********************************************
;		*               delay routines              *
;		*********************************************
;--------------------------------------------------------------------------

d2		movlw	D'255'
		movwf	TIMER2
DEL_LOOP1	movlw	D'255'
		movwf	TIMER1

DEL_LOOP2	DECFSZ	TIMER1,F
		goto	DEL_LOOP2
		DECFSZ	TIMER2,F
		goto	DEL_LOOP1
		return
;------------------------------------
;------------------------------------
dr3		call	d2
		call	d2
		call	d2
		call	d2
		return
;------------------------------------
;------------------------------------
dr2		MOVLW   D'060'
		MOVWF   TIMER2
DEL_LOOP1a	MOVLW   D'255'
		MOVWF   TIMER1

DEL_LOOP2a	DECFSZ  TIMER1,F
		GOTO    DEL_LOOP2a
		DECFSZ  TIMER2,F
		GOTO    DEL_LOOP1a
		return
;-----------------------------------------------------------------------------
d55		movlw	D'255'
		movwf	TIMER2
d55_loop	decfsz	TIMER2,F
		goto	d55_loop
		return
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------


;-----------------------------------------------------------------------------

;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

		END